@@ -3,6 +3,6 @@ from pathlib import Path
 
 sys.path.append(str(Path(__file__).parent))
 
-from _build import fetch_and_build_python_language
+from _build import py_language
 
-fetch_and_build_python_language()
+py_language(rebuild=True)
